package com.fractalite.hermes.teldar.cfg;

import com.fractalite.hermes.services.stay.ContentProviderDescriptor;



/**
 * TELDAR Content Provider Descriptor.
 * Supported Operations (Endpoints)
 * <ul>
 * 	<li>Hotel Search</li>
 *  <li>Hotel Quotes</li>
 *  <li>Order</li>
 *  <li>Property Description</li>
 * </ul>
 * Unsupported Operations
 * <ul>
 * 	<li>PreOrder</li>
 *  <li>Cancel PreOrder</li>
 * </ul>
 *
 */

public class ContentProvider implements ContentProviderDescriptor {

	public static final String PROVIDER_ID = "teldar";

	
	@Override
	public String getId() {
		return PROVIDER_ID;
	}

	@Override
	public String getQuoteSearchEndpoint() {
		return "nmr:" + TeldarRouteBuilder.EP_SEARCH;
	}
	
	@Override
	public String getPropertyQuoteEndpoint() {
		return "nmr:" + TeldarRouteBuilder.EP_HOTEL_QUOTES;
	}
	
	@Override
	public String getPropertyDescriptionEndpoint() {
		return "nmr:" + TeldarRouteBuilder.EP_HOTEL_INFO;
	}
	
	@Override
	public String getCancellationPolicy() {
		return "nmr:" + TeldarRouteBuilder.EP_HOTEL_QUOTE_CANCELLATION_POLICY;
	}
	
	@Override
	public String getPreOrderEndpoint() {
		return  "nmr:" + TeldarRouteBuilder.EP_ORDER;
	}
	
	@Override
	public String getOrderEndpoint() {
		return  "nmr:" + TeldarRouteBuilder.EP_GET_ORDER;
	}
	
	@Override
	public String getConfirmOrderEndpoint() {
		return  "nmr:" + TeldarRouteBuilder.EP_BOOKING_CONFIRMATION;
	}
	
	@Override
	public String getModifyOrderEndpoint() {
		return  null;
	}
	
	@Override
	public String getChargeConditionsEndpoint() {
		return null;
	}
	
	@Override
	public String getCancelPreOrderEndpoint() {
		return null;
	}

	@Override
	public String getCreateOrderEndpoint() {
		
		return null;
	}

	@Override
	public String getCancelOrderEndpoint() {
		//
		return "nmr:" + TeldarRouteBuilder.EP_CANCEL_ORDER;


	}


	@Override
	public String getCancellationQuoteEndpoint() {
		// TODO Auto-generated method stub
		return "nmr:" + TeldarRouteBuilder.EP_CANCELLATION_FEES;
	}
}
