package com.fractalite.hermes.teldar.parsers;

import java.io.IOException;
import java.text.ParseException;
import java.util.Currency;
import java.util.HashMap;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.xpath.XPathExpressionException;

import org.apache.camel.Exchange;
import org.apache.camel.InvalidPayloadException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.xml.sax.SAXException;

import com.fractalite.hermes.teldar.tools.ObjectToXml;
import com.fractalite.models.commerce.Order;
import com.fractalite.models.commerce.OrderStatus;
import com.fractalite.models.commerce.PriceScope;
import com.fractalite.models.common.Money;
import com.fractalite.models.travel.stay.HotelStay;
import com.gekko_holding.webservice.v2_4.CancellationFeesPolicy;
import com.gekko_holding.webservice.v2_4.CancellationPolicyResponse;
import com.gekko_holding.webservice.v2_4.GetPreBookingInfoResponse;

public class ParseAddBookingTeldar extends TeldarParsers {

	protected static Logger logger = LoggerFactory.getLogger(ParseAddBookingTeldar.class);

	@Override
	public void process(Exchange exchange) throws InvalidPayloadException, ParserConfigurationException, SAXException,
			IOException, XPathExpressionException, ParseException {


		logger.info("Invoking TELDAR ParseAddBookingTeldar Processor......." + exchange.getIn().getBody());
		Order oldOrder = exchange.getProperty("hermesorder", Order.class);
		GetPreBookingInfoResponse respbook = exchange.getIn().getBody(GetPreBookingInfoResponse.class);
		Order order = printHotelInfo(respbook.getPreBookingInfo(), oldOrder);
		logger.debug("new one " + ObjectToXml.printXML(order));
        exchange.setProperty("order", order);
    	exchange.getIn().setBody(order);
		logger.info("End TELDAR ParseAddBookingTeldar Processor.......");

	}


	private Order printHotelInfo(CancellationPolicyResponse teldarHotels, Order order) throws XPathExpressionException {

		if (teldarHotels != null && teldarHotels.getCancellationFeesPolicy() != null
				&& !teldarHotels.getCancellationFeesPolicy().isEmpty()) {

			logger.info("teldarHotels" + teldarHotels + "̣ size " + teldarHotels.getCancellationFeesPolicy().size());

			HashMap<String, HashMap<String, String>> cancellationFees = new HashMap<String, HashMap<String, String>>();

			for (CancellationFeesPolicy respHotelBook : teldarHotels.getCancellationFeesPolicy()) {

				if (!respHotelBook.isAllDates()) {
					if (respHotelBook.getFromDate() != null) {
						cancellationFees.put(respHotelBook.getFromDate(), new HashMap<String, String>());
					}

					if (respHotelBook.getToDate() != null) {
						cancellationFees.get(respHotelBook.getFromDate()).put("ToDate", respHotelBook.getToDate());
					}

					if (respHotelBook.getRoomIndex() != null) {
						cancellationFees.get(respHotelBook.getFromDate()).put("RoomIndex",
								respHotelBook.getRoomIndex().toString());
					}

					if (respHotelBook.getCurrency() != null) {
						cancellationFees.get(respHotelBook.getFromDate()).put("Currency", respHotelBook.getCurrency());
					}

					if (respHotelBook.getPrice() != null) {
						cancellationFees.get(respHotelBook.getFromDate()).put("Price", respHotelBook.getPrice());
					}
				} else {
					cancellationFees.put("allDates", new HashMap<String, String>());

					if (respHotelBook.getCurrency() != null) {
						cancellationFees.get("allDates").put("Currency", respHotelBook.getCurrency());
					}

					if (respHotelBook.getPrice() != null) {
						cancellationFees.get("allDates").put("Price", respHotelBook.getPrice());
					}
				}
			}

			if (teldarHotels.getVoucherObservation() != null && !teldarHotels.getVoucherObservation().isEmpty()) {
				HashMap<String, String> voucherMap = new HashMap<String, String>();
				voucherMap.put("voucher", teldarHotels.getVoucherObservation());
				cancellationFees.put("voucherObservation", voucherMap);
			}

			if (teldarHotels.getOfferCode() != null && !teldarHotels.getOfferCode().isEmpty()) {
//	               
				logger.info(" Offer codeteladr is : " + teldarHotels.getOfferCode());
				order.setNumber(teldarHotels.getOfferCode());
				order.setStatus(OrderStatus.PREORDER);
			} else
				try {
					throw (new Exception());
				} catch (Exception e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}

			if (teldarHotels.getOfferPrice() != null) {
				if (teldarHotels.getOfferPrice().isChanged()) {
					Money newMoney = new Money(teldarHotels.getOfferPrice().getTotalPrice().getValue(),
							Currency.getInstance(teldarHotels.getOfferPrice().getTotalPrice().getCurrency()));
					order.getPricing().setPrice(PriceScope.TOTAL, newMoney);

					logger.info("priceeeeeess " + teldarHotels.getOfferPrice().getTotalPrice().getCurrency());
					if (teldarHotels.getOfferPrice().getPricePerRoom() != null) {
						// Room pricing
					}
				}

				logger.info("Cancellation fees list content");
				for (String key : cancellationFees.keySet()) {
					for (String value : cancellationFees.get(key).keySet()) {
						logger.info(key);
						logger.info(value + " : " + cancellationFees.get(key).get(value));
						logger.info("vaueeeeeeeeeeee " + cancellationFees.get(key).get(value));
					}
				}

			}

		}

		logger.debug("new one in processorPreOrder1  " + ObjectToXml.printXML(order));
		return order;

	}
}
